@@ -173,7 +173,7 @@ class ImageWithAnnotation(dict):
             blend_dir = pathjoin(dataset_dir, "blend")
             os.makedirs(blend_dir, exist_ok=True)
             blend_path = pathjoin(blend_dir, fname + ".blend")
-            bpy.ops.wm.save_mainfile(filepath=blend_path)
+            bpy.ops.wm.save_mainfile(filepath=os.path.abspath(blend_path))
         # save image at last for unstable compute enviroment
         if self.get("image") is not None:
             image_dir = pathjoin(dataset_dir, "image")
